hash stringlengths 40 40 | diff stringlengths 131 114k | message stringlengths 7 980 | project stringlengths 5 67 | split stringclasses 1
value |
|---|---|---|---|---|
89a9ff3345943d7e0bfcfe1043c64f76dad7edb9 | diff --git a/api/server/apps_delete.go b/api/server/apps_delete.go
index <HASH>..<HASH> 100644
--- a/api/server/apps_delete.go
+++ b/api/server/apps_delete.go
@@ -28,7 +28,7 @@ func handleAppDelete(c *gin.Context) {
return
}
- err = Api.FireAfterAppDelete(ctx, appName)
+ err = Api.FireBeforeAppDelete(ctx, appNam... | fix app delete listener call (#<I>) | iron-io_functions | train |
167138fd6535d6ac994e6c6f4ed8b7a4536d0586 | diff --git a/cmd/cammount/cammount.go b/cmd/cammount/cammount.go
index <HASH>..<HASH> 100644
--- a/cmd/cammount/cammount.go
+++ b/cmd/cammount/cammount.go
@@ -74,8 +74,13 @@ func main() {
sigc := make(chan os.Signal, 1)
go func() {
var buf [1]byte
- os.Stdin.Read(buf[:])
- log.Printf("Read from stdin; shu... | cammount: quieter. and only exit when 'q' is pressed.
Change-Id: I2c<I>f<I>d<I>e<I>cd<I>ce<I>dd<I> | perkeep_perkeep | train |
582d563098f5fcf244bf0e7bbcd1d1d9fcbf8cf2 | diff --git a/packages/idyll-cli/src/client/build.js b/packages/idyll-cli/src/client/build.js
index <HASH>..<HASH> 100644
--- a/packages/idyll-cli/src/client/build.js
+++ b/packages/idyll-cli/src/client/build.js
@@ -19,6 +19,7 @@ require('__IDYLL_SYNTAX_HIGHLIGHT__');
var opts = require('__IDYLL_OPTS__');
var layout =... | have authorView value flow to runtime | idyll-lang_idyll | train |
17908008f90ab56a7f3dff41ea036c3eadfb3dfa | diff --git a/spec/httmultiparty_spec.rb b/spec/httmultiparty_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/httmultiparty_spec.rb
+++ b/spec/httmultiparty_spec.rb
@@ -13,7 +13,7 @@ describe HTTMultiParty do
let(:klass) { Class.new.tap { |k| k.instance_eval { include HTTMultiParty} } }
it "should include HTTPart... | Added test case for verifying that position of file and non-file params does not matter | jwagener-soundcloud_httmultiparty | train |
37adfb8ed5c1f821af731be16513b88414732ad8 | diff --git a/telemetry/telemetry/core/backends/form_based_credentials_backend.py b/telemetry/telemetry/core/backends/form_based_credentials_backend.py
index <HASH>..<HASH> 100644
--- a/telemetry/telemetry/core/backends/form_based_credentials_backend.py
+++ b/telemetry/telemetry/core/backends/form_based_credentials_back... | [telemetry] Add credentials login url to be overridden
When working with staging systems, you need to be able to provide an
alternative login url.
R=tonyg,dtu
Review URL: <URL> | catapult-project_catapult | train |
d9fc41ed7421a5765522de6d4f8300771254ae3b | diff --git a/tests/unit/concurrently/test_HTCondorJobSubmitter.py b/tests/unit/concurrently/test_HTCondorJobSubmitter.py
index <HASH>..<HASH> 100644
--- a/tests/unit/concurrently/test_HTCondorJobSubmitter.py
+++ b/tests/unit/concurrently/test_HTCondorJobSubmitter.py
@@ -6,6 +6,8 @@ import textwrap
import pytest
+p... | skit tests for htcondor | alphatwirl_alphatwirl | train |
e73f867464caf5d3fd030d41513768512b60010b | diff --git a/sdc/rabbit/publisher.py b/sdc/rabbit/publisher.py
index <HASH>..<HASH> 100644
--- a/sdc/rabbit/publisher.py
+++ b/sdc/rabbit/publisher.py
@@ -101,11 +101,6 @@ class QueuePublisher(object):
logger.debug("Publishing message")
try:
self._connect()
- except pika.exceptions... | Reduce the about of try/except blocks | ONSdigital_sdc-rabbit | train |
4da1be0423975ca5da8282802e949fac3058f5a2 | diff --git a/openstack_dashboard/dashboards/project/images/images/forms.py b/openstack_dashboard/dashboards/project/images/images/forms.py
index <HASH>..<HASH> 100644
--- a/openstack_dashboard/dashboards/project/images/images/forms.py
+++ b/openstack_dashboard/dashboards/project/images/images/forms.py
@@ -84,7 +84,6 @@... | Use URLField instead of CharField for image_url
The image location for 'create image' is an external url to load the
image from, so it's more suitable to use URLField instead of CharField.
Change-Id: Ib<I>dbd<I>ec<I>df<I>b<I>ffe<I>a0a
Closes-bug: #<I> | openstack_horizon | train |
5b13909aba6bd04e643a7c2063cc293807010f31 | diff --git a/src/level/TMXTiledMap.js b/src/level/TMXTiledMap.js
index <HASH>..<HASH> 100644
--- a/src/level/TMXTiledMap.js
+++ b/src/level/TMXTiledMap.js
@@ -99,6 +99,9 @@
* @ignore
*/
function readImageLayer(map, data, z) {
+ // Normalize properties
+ me.TMXUtils.applyTMXProperties(data... | Fix ImageLayer property normalization with JSON format maps
- Broken by 6cec<I>c4c1a1ecab<I>edb<I>d<I>a7bcb<I>a<I>c | melonjs_melonJS | train |
a4ce9ebfe5d8a1336cd441ee68baf1db04abdcea | diff --git a/cf/app_files/app_files.go b/cf/app_files/app_files.go
index <HASH>..<HASH> 100644
--- a/cf/app_files/app_files.go
+++ b/cf/app_files/app_files.go
@@ -139,9 +139,9 @@ func (appfiles ApplicationFiles) WalkAppFiles(dir string, onEachFile func(string
}
if runtime.GOOS == "windows" {
- fi, err := o... | Fix go vet issue in app_files | cloudfoundry_cli | train |
7b923d6c72be29e2fe57740c9ea3a2135e7db6f7 | diff --git a/tests/thread/stress_aes.py b/tests/thread/stress_aes.py
index <HASH>..<HASH> 100644
--- a/tests/thread/stress_aes.py
+++ b/tests/thread/stress_aes.py
@@ -235,7 +235,7 @@ class LockedCounter:
count = LockedCounter()
-def thread_entry():
+def thread_entry(n_loop):
global count
aes = AES(256)... | tests/thread: Make stress_aes.py test run on bare-metal ports.
This is a long-running test, so make it run in reasonable time on slower,
bare-metal ports. | micropython_micropython | train |
a01947e1e9c214490fb628516d625e028b76cd43 | diff --git a/django_geoip/models.py b/django_geoip/models.py
index <HASH>..<HASH> 100644
--- a/django_geoip/models.py
+++ b/django_geoip/models.py
@@ -159,13 +159,13 @@ class GeoLocationFacade(models.Model):
class GeoLocationFascade(GeoLocationFacade):
""" Old alias with a typo """
- def __init__(self, **kwa... | Fixing init signature for deprecated class
#<I> | futurecolors_django-geoip | train |
31c0f0a911c16ad854bc11cac1bb602c5f0a8ef0 | diff --git a/pkg/cmd/cli/describer.go b/pkg/cmd/cli/describer.go
index <HASH>..<HASH> 100644
--- a/pkg/cmd/cli/describer.go
+++ b/pkg/cmd/cli/describer.go
@@ -1,6 +1,7 @@
package cli
import (
+ "fmt"
"strings"
"text/tabwriter"
@@ -40,8 +41,37 @@ type BuildDescriber struct {
client.Interface
}
+func (d *B... | Add strategy and revision output to Build describer | openshift_origin | train |
b2f869d8a23f891d2c1d52da9d63666fbbdf954d | diff --git a/tasklib/tests.py b/tasklib/tests.py
index <HASH>..<HASH> 100644
--- a/tasklib/tests.py
+++ b/tasklib/tests.py
@@ -4,7 +4,7 @@ import shutil
import tempfile
import unittest
-from .task import TaskWarrior
+from .task import TaskWarrior, Task
class TasklibTest(unittest.TestCase):
@@ -23,24 +23,24 @@ ... | tests: Do not use TW directly to create tasks | robgolding_tasklib | train |
1e68b834a6bb047ca83d3c588847d34f47a6a637 | diff --git a/xwiki-commons-core/xwiki-commons-job/src/test/java/org/xwiki/job/internal/DefaultJobProgressTest.java b/xwiki-commons-core/xwiki-commons-job/src/test/java/org/xwiki/job/internal/DefaultJobProgressTest.java
index <HASH>..<HASH> 100644
--- a/xwiki-commons-core/xwiki-commons-job/src/test/java/org/xwiki/job/in... | XCOMMONS-<I>: When starting/stoping a progress step with a different source, the progress tree might get broken | xwiki_xwiki-commons | train |
c008d010f9fa6ec9c4ea8ccd25641d10833ee61a | diff --git a/stories/RenderCounter/DivRefreshable.js b/stories/RenderCounter/DivRefreshable.js
index <HASH>..<HASH> 100644
--- a/stories/RenderCounter/DivRefreshable.js
+++ b/stories/RenderCounter/DivRefreshable.js
@@ -10,7 +10,7 @@ import withNestHandlers from './withNestHandlers';
const DivRefreshable = ({ label, ... | refactor(withNestHandlers): pass next if argLen>1 | Stupidism_stupid-rc-starter | train |
dea1343e749fcf998b0d283e738917d193491f50 | diff --git a/test/k8sT/Services.go b/test/k8sT/Services.go
index <HASH>..<HASH> 100644
--- a/test/k8sT/Services.go
+++ b/test/k8sT/Services.go
@@ -1037,7 +1037,7 @@ Secondary Interface %s :: IPv4: (%s, %s), IPv6: (%s, %s)`, helpers.DualStackSupp
})
})
- Context("Tests with direct routing", func() {
+ ... | test/Services: Quarantine 'Tests with direct routing'
CC: Martynas Pumputis <<EMAIL>> | cilium_cilium | train |
1ba8128445cf7f6751c8a3ecb2565e7e02be5ada | diff --git a/src/RangeCalendar.js b/src/RangeCalendar.js
index <HASH>..<HASH> 100644
--- a/src/RangeCalendar.js
+++ b/src/RangeCalendar.js
@@ -1,4 +1,5 @@
import React, { PropTypes } from 'react';
+import { findDOMNode } from 'react-dom';
import GregorianCalendar from 'gregorian-calendar';
import classnames from 'cl... | Fix RangePicker focus error
close ant-design/ant-design#<I> | react-component_calendar | train |
a6b18ae120f4a8ba74b255975c21ce9c730266a6 | diff --git a/modules/adfBidAdapter.js b/modules/adfBidAdapter.js
index <HASH>..<HASH> 100644
--- a/modules/adfBidAdapter.js
+++ b/modules/adfBidAdapter.js
@@ -15,7 +15,10 @@ const { getConfig } = config;
const BIDDER_CODE = 'adf';
const GVLID = 50;
-const BIDDER_ALIAS = [ { code: 'adformOpenRTB', gvlid: GVLID } ];
... | Adf Bid Adapter: add adform alias (#<I>) | prebid_Prebid.js | train |
f489a00deec0e8ebe8574c83d8cca3f5b856ce4f | diff --git a/packages/node_modules/@webex/internal-plugin-conversation/test/integration/spec/verbs.js b/packages/node_modules/@webex/internal-plugin-conversation/test/integration/spec/verbs.js
index <HASH>..<HASH> 100644
--- a/packages/node_modules/@webex/internal-plugin-conversation/test/integration/spec/verbs.js
+++ ... | test(i-p-conversation): remove mercury logic from typing tests | webex_spark-js-sdk | train |
f734d842f5ee2e67be253dd78784664e8fc3bac0 | diff --git a/client/driver/qemu.go b/client/driver/qemu.go
index <HASH>..<HASH> 100644
--- a/client/driver/qemu.go
+++ b/client/driver/qemu.go
@@ -33,6 +33,7 @@ var (
// Prior to qemu 2.10.1, monitor socket paths are truncated to 108 bytes.
// We should consider this if driver.qemu.version is < 2.10.1 and the
// ... | Qemu driver: clean up logging; fail unsupported features on Windows | hashicorp_nomad | train |
de444867d3de7abcb6e15e456a63672b3b2a6cb0 | diff --git a/packer/environment_test.go b/packer/environment_test.go
index <HASH>..<HASH> 100644
--- a/packer/environment_test.go
+++ b/packer/environment_test.go
@@ -3,6 +3,7 @@ package packer
import (
"bytes"
"cgl.tideland.biz/asserts"
+ "errors"
"fmt"
"os"
"strings"
@@ -67,6 +68,31 @@ func TestEnvironment... | packer: Tests for the Builder error cases | hashicorp_packer | train |
d92690dd9ff4c365b0ed73e838843e0add528de7 | diff --git a/connection.go b/connection.go
index <HASH>..<HASH> 100644
--- a/connection.go
+++ b/connection.go
@@ -162,20 +162,26 @@ func (connection *redisConnection) getConsumingQueues() ([]string, error) {
// heartbeat keeps the heartbeat key alive
func (connection *redisConnection) heartbeat(errors chan<- error... | Add error count to heartbeat and consume errors
So the caller can see how often these errors happened consecutively. | adjust_rmq | train |
80d9d7cc31f3ee99da6af0e66fa608cfa60ad703 | diff --git a/packages/material-ui/src/Tooltip/Tooltip.js b/packages/material-ui/src/Tooltip/Tooltip.js
index <HASH>..<HASH> 100644
--- a/packages/material-ui/src/Tooltip/Tooltip.js
+++ b/packages/material-ui/src/Tooltip/Tooltip.js
@@ -482,6 +482,19 @@ const Tooltip = React.forwardRef(function Tooltip(props, ref) {
... | [Tooltip] Fix popper.js re-instantiation (#<I>) | mui-org_material-ui | train |
6fde40915316dbc378f5932136ddb14a522cb416 | diff --git a/src/Backbone.CollectionView.js b/src/Backbone.CollectionView.js
index <HASH>..<HASH> 100755
--- a/extension/rsb/com/src/main/java/org/openbase/jul/extension/rsb/com/RSBRemoteService.java
+++ ... | reinit in RSBRemoteService is now skipped from ping and asynMethodCall of the InvalidState is triggered by another thread reinitializing | openbase_jul | train |
cb285221eccd51e76a8ed9db948c3f4806b7ead5 | diff --git a/Lib/fontMath/mathKerning.py b/Lib/fontMath/mathKerning.py
index <HASH>..<HASH> 100644
--- a/Lib/fontMath/mathKerning.py
+++ b/Lib/fontMath/mathKerning.py
@@ -62,6 +62,22 @@ class MathKerning(object):
g[groupName].append(glyphName)
return g
+ def getGroupsForGlyph(self, gl... | Added a method for getting the list of groups that a glyph belongs to. | robotools_fontMath | train |
94e7ceb700b8d7f5171e1d615ac7fd09068e63b7 | diff --git a/nion/swift/model/DocumentModel.py b/nion/swift/model/DocumentModel.py
index <HASH>..<HASH> 100644
--- a/nion/swift/model/DocumentModel.py
+++ b/nion/swift/model/DocumentModel.py
@@ -1104,6 +1104,8 @@ class DocumentModel(Observable.Observable, ReferenceCounting.ReferenceCounted, P
self.__data_chann... | Allow hardware sources to put function calls on main thread (call_soon). | nion-software_nionswift | train |
19b2cddc3c2f8346b36d8ad50afaefbf150b9686 | diff --git a/source/php/Responses.php b/source/php/Responses.php
index <HASH>..<HASH> 100644
--- a/source/php/Responses.php
+++ b/source/php/Responses.php
@@ -159,6 +159,10 @@ class Responses
*/
public function addPageSummaryMetaBox($postType, $post)
{
+ if (!isset($post->ID)) {
+ retu... | Do not run code if $post is null | helsingborg-stad_Customer-feedback | train |
d4393e51401ed36ea7e4d8aa0bb6d7c301b05da9 | diff --git a/salt/cloud/clouds/joyent.py b/salt/cloud/clouds/joyent.py
index <HASH>..<HASH> 100644
--- a/salt/cloud/clouds/joyent.py
+++ b/salt/cloud/clouds/joyent.py
@@ -1134,5 +1134,3 @@ def query(action=None,
return_content = yaml.safe_load(content)
return [result['status'], return_content]
-
- | Remove blank lines at end of file to satisfy linter | saltstack_salt | train |
30f2dec97f5f7e72cf539d4d80a54813744a5e6d | diff --git a/core/src/main/java/hudson/model/ListView.java b/core/src/main/java/hudson/model/ListView.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/hudson/model/ListView.java
+++ b/core/src/main/java/hudson/model/ListView.java
@@ -172,11 +172,18 @@ public class ListView extends View implements DirectlyModif... | Cleanup the code integrated in #<I> | jenkinsci_jenkins | train |
ad9d699d98fc224b922bcd8533cc6771238720ff | diff --git a/messages/sync.js b/messages/sync.js
index <HASH>..<HASH> 100644
--- a/messages/sync.js
+++ b/messages/sync.js
@@ -26,7 +26,7 @@ module.exports = {
}
}
- data.push(entries[i][0], meta)
+ data.unshift(entries[i][0], meta)
}
this.syncing += 1
diff --git a/test/sync.test... | Fix actions adding order on sync with multiple actions | logux_core | train |
ffef34c1a92ca8299914988df8b289c935215c80 | diff --git a/Form/DataType.php b/Form/DataType.php
index <HASH>..<HASH> 100644
--- a/Form/DataType.php
+++ b/Form/DataType.php
@@ -51,6 +51,9 @@ class DataType extends \Sidus\EAVModelBundle\Form\DataType
{
$resolver->setDefaults([
'data_class' => $this->dataClass,
+ 'attr' => [
+ ... | Minor changes: disabling html5 validation by default, adding comment in sortable js | VincentChalnot_SidusEAVBootstrapBundle | train |
d7f31a3322ea2d2aa6c10e6ae07efbfb8b331552 | diff --git a/lib/discordrb/data.rb b/lib/discordrb/data.rb
index <HASH>..<HASH> 100644
--- a/lib/discordrb/data.rb
+++ b/lib/discordrb/data.rb
@@ -247,7 +247,7 @@ module Discordrb
# (Coincidentally, Manage Permissions is the same permission as Manage Roles, and a
# Manage Permissions deny overwrite will o... | Update permission name in data.rb | meew0_discordrb | train |
6292375f261d92479a4d31b5beb6bf1fb180c2fb | diff --git a/lib/node-libnmap.js b/lib/node-libnmap.js
index <HASH>..<HASH> 100644
--- a/lib/node-libnmap.js
+++ b/lib/node-libnmap.js
@@ -317,21 +317,16 @@ var version = 'v0.0.3'
},
/**
- * @function replace
- * @abstract Performs recursive replacement on array of hosts to split
- * C... | validate method
Methods:
validate: Structure for API now the following -
net: Object of REGEX pattern matching
perform(regex, str): Function to perform specified
pattern matching test on string | jas-_node-libnmap | train |
4f9123ebe2fa382b1d1b2c6f3cc78869cc924bb8 | diff --git a/pkg/services/provisioning/plugins/plugin_provisioner.go b/pkg/services/provisioning/plugins/plugin_provisioner.go
index <HASH>..<HASH> 100644
--- a/pkg/services/provisioning/plugins/plugin_provisioner.go
+++ b/pkg/services/provisioning/plugins/plugin_provisioner.go
@@ -47,7 +47,6 @@ func (ap *PluginProvisi... | Provisioning: always pin app to the sidebar when enabled (#<I>) | grafana_grafana | train |
223730cae46c069038ae0b8f0256315d9bf5ca06 | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -12,7 +12,7 @@ setup(
long_description=get_readme(),
author="nGen Works",
author_email='tech@ngenworks.com',
- url='http://www.ngenworks.com',
+ url='https://github.com/ngenworks/rest_framework_ember',
... | Change url in setup.py | django-json-api_django-rest-framework-json-api | train |
e34b34d2a3241b1079b91a781cd48d80f838de9e | diff --git a/src/Models/User.php b/src/Models/User.php
index <HASH>..<HASH> 100644
--- a/src/Models/User.php
+++ b/src/Models/User.php
@@ -56,7 +56,7 @@ class User extends ActiveRecord
TigerApp::log("Password for {$this->username} rehashed.");
}
return true;
- }else {
+ } else {
retu... | Scrutinizer Auto-Fixes
This commit consists of patches automatically generated for this project on <URL> | Thruio_TigerKit | train |
fa26a94edca6b064d16a8d40700d63090af6bd4d | diff --git a/CHANGELOG.md b/CHANGELOG.md
index <HASH>..<HASH> 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -19,6 +19,7 @@
* [#2175](https://github.com/bbatsov/rubocop/pull/2175): Files that are excluded from a cop (e.g. using the `Exclude:` config option) are no longer being processed by that cop. ([@bquorning][])
... | Handle class methods in EmptyLineBetweenDefs
I've made it check `defs` node type as well as `def`, that's the
only change that was needed to make it work with class methods. | rubocop-hq_rubocop | train |
82e936cc81f75d35fc83b49f91a1cf1ce22f9508 | diff --git a/ga4gh/cli.py b/ga4gh/cli.py
index <HASH>..<HASH> 100644
--- a/ga4gh/cli.py
+++ b/ga4gh/cli.py
@@ -192,6 +192,18 @@ class AbstractSearchRunner(FormattedOutputRunner):
for readGroupSet in iterator:
yield readGroupSet
+ def getAllReadGroups(self):
+ """
+ Get a... | Added support for finding all read groups when no read group specified
Fixes issue #<I> | ga4gh_ga4gh-server | train |
14ab43a310d9391b8b3eded0e20700bd7e8f9cde | diff --git a/src/Tenant/Views/SpaRepository.php b/src/Tenant/Views/SpaRepository.php
index <HASH>..<HASH> 100644
--- a/src/Tenant/Views/SpaRepository.php
+++ b/src/Tenant/Views/SpaRepository.php
@@ -34,7 +34,7 @@ class Tenant_Views_SpaRepository extends Pluf_Views
{
// request param
$backend = Pl... | Edit used API to connection with remote repository | pluf_tenant | train |
d032af4205fd6be01f1574025e820ebf28015fe4 | diff --git a/src/main/java/org/asteriskjava/manager/action/SipPeersAction.java b/src/main/java/org/asteriskjava/manager/action/SipPeersAction.java
index <HASH>..<HASH> 100644
--- a/src/main/java/org/asteriskjava/manager/action/SipPeersAction.java
+++ b/src/main/java/org/asteriskjava/manager/action/SipPeersAction.java
@... | [AJ-<I>] Fixed workaround for Asterisk bug in SipShowPeerResponse | asterisk-java_asterisk-java | train |
a0743e9a6e3c193f92e0e796714f8bebac424381 | diff --git a/xchange-binance/src/main/java/org/knowm/xchange/binance/BinanceAdapters.java b/xchange-binance/src/main/java/org/knowm/xchange/binance/BinanceAdapters.java
index <HASH>..<HASH> 100644
--- a/xchange-binance/src/main/java/org/knowm/xchange/binance/BinanceAdapters.java
+++ b/xchange-binance/src/main/java/org/... | Added cumulativeQuoteAmount method into Order & refactored CoinbasePro adaptOrder | knowm_XChange | train |
6752cf8e32ba7fbf27d38288ef9c5ee0abd89f87 | diff --git a/snappy-core/src/main/java/io/joshworks/snappy/SnappyServer.java b/snappy-core/src/main/java/io/joshworks/snappy/SnappyServer.java
index <HASH>..<HASH> 100644
--- a/snappy-core/src/main/java/io/joshworks/snappy/SnappyServer.java
+++ b/snappy-core/src/main/java/io/joshworks/snappy/SnappyServer.java
@@ -432,7... | Exiting process if exception on startup occurs | josueeduardo_snappy | train |
866fb866f0460cf27c31ff2f4ae0253e9abddd61 | diff --git a/CHANGES.md b/CHANGES.md
index <HASH>..<HASH> 100644
--- a/CHANGES.md
+++ b/CHANGES.md
@@ -7,6 +7,7 @@ Change Log
* Fixed a bug that caused an 'added' and a 'shown' event for "Unnamed Item" to be logged to Google Analytics when previewing an item in the catalog.
* Added a 'preview' Google Analytics even... | fix csv files with missing dates fail to load | TerriaJS_terriajs | train |
16b9271e5c684cd7729fa3906032536509e3a4a0 | diff --git a/lib/async.js b/lib/async.js
index <HASH>..<HASH> 100644
--- a/lib/async.js
+++ b/lib/async.js
@@ -139,7 +139,8 @@
}
while (running < limit && started < arr.length) {
- iterator(arr[started], function (err) {
+ started += 1;
+ iterator(arr[s... | fix occasional synchronous use of forEachLimit | caolan_async | train |
e29c5c9f4b22b427dc51ca7c39f458f5f5e3e595 | diff --git a/icrawler/builtin/bing.py b/icrawler/builtin/bing.py
index <HASH>..<HASH> 100644
--- a/icrawler/builtin/bing.py
+++ b/icrawler/builtin/bing.py
@@ -4,12 +4,7 @@ import re
import six
from bs4 import BeautifulSoup
-try:
- import html
- unescape = html.unescape
-except ImportError:
- from six.move... | Remove <I> and <I> - <I> Support | hellock_icrawler | train |
a84a738360f1986f67b4a2d72005ef6848761601 | diff --git a/internal/ui/ui_glfw_darwin.go b/internal/ui/ui_glfw_darwin.go
index <HASH>..<HASH> 100644
--- a/internal/ui/ui_glfw_darwin.go
+++ b/internal/ui/ui_glfw_darwin.go
@@ -147,13 +147,13 @@ package ui
//
// // Even though EbitenWindowDelegate is used, this hack is still required.
// // toggleFullscreen do... | internal/ui: bug fix: collectionBehavior mattered for fullscreen
Closes #<I> | hajimehoshi_ebiten | train |
4326c47b24f7e3c58010e97f31d176bf960c5182 | diff --git a/telemetry/telemetry/core/cast_interface.py b/telemetry/telemetry/core/cast_interface.py
index <HASH>..<HASH> 100644
--- a/telemetry/telemetry/core/cast_interface.py
+++ b/telemetry/telemetry/core/cast_interface.py
@@ -3,6 +3,14 @@
# found in the LICENSE file.
"""A wrapper for common operations on a devic... | [cast3p] Set defaults for Cast Core remote device testing
This makes it easier for developers to use our base test scenario,
where the binaries are checked out in Chromium.
Bug: chromium:<I>
Change-Id: I<I>ad<I>b6a4f<I>e<I>e<I>e7e2bde<I>b<I>f
Reviewed-on: <URL> | catapult-project_catapult | train |
bc39baa13253da299d062565be1406e69b90a4f1 | diff --git a/apio/managers/scons.py b/apio/managers/scons.py
index <HASH>..<HASH> 100644
--- a/apio/managers/scons.py
+++ b/apio/managers/scons.py
@@ -216,13 +216,13 @@ class SCons(object):
def get_serial_port(self, board, board_data, ext_serial_port):
# Search Serial port by USB id
- device = se... | Throw error "board not available" only if no serial/ftdi devices are found | FPGAwars_apio | train |
3d72d47f0905772b83d02159400a7d7f9af40c4e | diff --git a/src/transformers/models/mpnet/modeling_tf_mpnet.py b/src/transformers/models/mpnet/modeling_tf_mpnet.py
index <HASH>..<HASH> 100644
--- a/src/transformers/models/mpnet/modeling_tf_mpnet.py
+++ b/src/transformers/models/mpnet/modeling_tf_mpnet.py
@@ -348,15 +348,22 @@ class TFMPNetEncoder(tf.keras.layers.La... | Making TF MPNet model compliant with XLA (#<I>)
* Fix XLA
* Rework cast
* Apply style | huggingface_pytorch-pretrained-BERT | train |
f037acaed7b057a8124624b20bcfbd083fc8ecff | diff --git a/pandas/tests/io/pytables/__init__.py b/pandas/tests/io/pytables/__init__.py
index <HASH>..<HASH> 100644
--- a/pandas/tests/io/pytables/__init__.py
+++ b/pandas/tests/io/pytables/__init__.py
@@ -6,4 +6,7 @@ pytestmark = [
"ignore:a closed node found in the registry:UserWarning"
),
pytest.... | CI: numpy warnings produced by pytables (#<I>) | pandas-dev_pandas | train |
ba51f1097db26a15b984b02c40a868d081f18d9a | diff --git a/.azure-pipelines.yml b/.azure-pipelines.yml
index <HASH>..<HASH> 100644
--- a/.azure-pipelines.yml
+++ b/.azure-pipelines.yml
@@ -2,53 +2,51 @@ trigger:
- master
jobs:
- - job: PyTest
- pool:
- vmImage: 'ubuntu-16.04'
- strategy:
- matrix:
- Python37:
- py... | New pip resolver (#<I>) | theislab_scanpy | train |
1e4543c30e065ff07c3acd55053648c6fd481c44 | diff --git a/cli/src/main/java/org/jboss/as/cli/impl/DefaultOperationRequestParser.java b/cli/src/main/java/org/jboss/as/cli/impl/DefaultOperationRequestParser.java
index <HASH>..<HASH> 100644
--- a/cli/src/main/java/org/jboss/as/cli/impl/DefaultOperationRequestParser.java
+++ b/cli/src/main/java/org/jboss/as/cli/impl/... | differentiate between ':' being an address/operation name separator and a part of a parameter value | wildfly_wildfly | train |
8652dc996e0d25784954a998aeadd5413af02f10 | diff --git a/src/main/java/edu/ksu/canvas/impl/UserImpl.java b/src/main/java/edu/ksu/canvas/impl/UserImpl.java
index <HASH>..<HASH> 100644
--- a/src/main/java/edu/ksu/canvas/impl/UserImpl.java
+++ b/src/main/java/edu/ksu/canvas/impl/UserImpl.java
@@ -39,7 +39,7 @@ public class UserImpl extends BaseImpl<User, UserReader... | corrected url for userImpl. | kstateome_canvas-api | train |
2bd317e9288823f4c602b0ac314e72407bcb5ef6 | diff --git a/src/js/form-builder.js b/src/js/form-builder.js
index <HASH>..<HASH> 100644
--- a/src/js/form-builder.js
+++ b/src/js/form-builder.js
@@ -2017,15 +2017,18 @@ const FormBuilder = function (opts, element, $) {
}
})
- $stage.children(rowWrapperClassSelector).each((i, elem) => {
- if ($(e... | Ensure row is deleted when no more cols exist | kevinchappell_formBuilder | train |
3c44fc3e6bc81b77c611078907d62070cdb0e873 | diff --git a/rdopkg/utils/specfile.py b/rdopkg/utils/specfile.py
index <HASH>..<HASH> 100644
--- a/rdopkg/utils/specfile.py
+++ b/rdopkg/utils/specfile.py
@@ -325,11 +325,10 @@ class Spec(object):
"""Return a tuple (version, number_of_commits) that are parsed
from the patches_base in the specfile.
... | specfile: convert to using get_magic_comment
* now that we have functionality swap out duplicate
regex for get_magic_comment method which is available
* replace duplicate logic in get_patches_base and get_patches_ignore_regex
Change-Id: Id<I>da2be1b9a<I>d4f<I> | softwarefactory-project_rdopkg | train |
c27c344ffd0e30029b613cc0c0e8718a0789a9ee | diff --git a/src/circuit.js b/src/circuit.js
index <HASH>..<HASH> 100644
--- a/src/circuit.js
+++ b/src/circuit.js
@@ -43,7 +43,9 @@ class Circuit {
this.dialer = new CircuitDialer(swarm, options)
- this.swarm.on('peer-mux-established', this.dialer.canHop.bind(this.dialer))
+ this.swarm.on('peer-mux-esta... | fix: connection establishment event handling (#<I>) | libp2p_js-libp2p-circuit | train |
78d6dda005ca304d5e021e977d361a8d09d736df | diff --git a/builder/digitalocean/api.go b/builder/digitalocean/api.go
index <HASH>..<HASH> 100644
--- a/builder/digitalocean/api.go
+++ b/builder/digitalocean/api.go
@@ -5,12 +5,16 @@
package digitalocean
type Region struct {
- Id uint `json:"id,omitempty"` //only in v1 api
- Slug string `... | builder/digitalocean: fix response decoding after api changes | hashicorp_packer | train |
7f2837ea4c6250bb566ec8b0ed8d87d2c58c89f7 | diff --git a/eos/eos.go b/eos/eos.go
index <HASH>..<HASH> 100644
--- a/eos/eos.go
+++ b/eos/eos.go
@@ -11,6 +11,7 @@ import (
"strconv"
"github.com/itchio/httpkit/httpfile"
+ "github.com/itchio/httpkit/retrycontext"
"github.com/itchio/wharf/eos/option"
"github.com/pkg/errors"
)
@@ -105,6 +106,10 @@ func real... | Add a bunch of options for eos.Open (HTTPClient, MaxTries, Consumer) | itchio_wharf | train |
fcfc99d92df9738d712ef0250335c2ee65dabd15 | diff --git a/lib/seeder.js b/lib/seeder.js
index <HASH>..<HASH> 100644
--- a/lib/seeder.js
+++ b/lib/seeder.js
@@ -2,11 +2,12 @@ var Seed = require('./seed');
var log = require('./log');
var dbmUtil = require('./util');
var Promise = require('bluebird');
+var SeederInterface = require( './interface/seederInterface.j... | add reducteToInterface to seeder | db-migrate_node-db-migrate | train |
c33cae8bc099908fc5ce58f03d469601417cc10d | diff --git a/jsmpp-examples/src/main/java/org/jsmpp/examples/SimpleSubmitExample.java b/jsmpp-examples/src/main/java/org/jsmpp/examples/SimpleSubmitExample.java
index <HASH>..<HASH> 100644
--- a/jsmpp-examples/src/main/java/org/jsmpp/examples/SimpleSubmitExample.java
+++ b/jsmpp-examples/src/main/java/org/jsmpp/example... | Correcting double quotation mark position
at NegativeResponseException case | opentelecoms-org_jsmpp | train |
03bcf911253b3195c6afe5ea70a6e61c73c93575 | diff --git a/lib/giston/commands.rb b/lib/giston/commands.rb
index <HASH>..<HASH> 100644
--- a/lib/giston/commands.rb
+++ b/lib/giston/commands.rb
@@ -30,11 +30,16 @@ module Giston
msg "Local revision: #{local_revision}. Remote revision: #{remote_revision}"
if git.local_directory_exists?(mirror["dir"])
... | Add a friendlier message when the remote and local revsions are the same [Ferdinand Svehla] | cristibalan_braid | train |
03916cd0e367bbf20d7acd2f01844f64e4aef7d3 | diff --git a/src/dar/UnpackedDarFolderStorage.js b/src/dar/UnpackedDarFolderStorage.js
index <HASH>..<HASH> 100644
--- a/src/dar/UnpackedDarFolderStorage.js
+++ b/src/dar/UnpackedDarFolderStorage.js
@@ -3,7 +3,7 @@ import FSStorage from './FSStorage'
/**
* A storage implementation that is bound to a single folder.
... | Add test for reading a dar from folder. | substance_texture | train |
e922bbb7e6c26ae81e679f4ec03fff0c1e602758 | diff --git a/test/filter_hc_somatic_test.py b/test/filter_hc_somatic_test.py
index <HASH>..<HASH> 100644
--- a/test/filter_hc_somatic_test.py
+++ b/test/filter_hc_somatic_test.py
@@ -47,8 +47,8 @@ class FilterSomaticTestCase(unittest.TestCase):
in_files = [input1, input2]
somatic... | ex-<I> fixed erroneous test | umich-brcf-bioinf_Jacquard | train |
a08cd04f3429b90b123f6e505411704558273e34 | diff --git a/location_provider_impl.go b/location_provider_impl.go
index <HASH>..<HASH> 100644
--- a/location_provider_impl.go
+++ b/location_provider_impl.go
@@ -24,7 +24,10 @@ func testCallerInfo(skip int) (testName string, path string, line int) {
}
func callerInfo(skip int) (methodName string, path string, line... | you shall not pass wrong arguments to provideLocation | assertgo_assert | train |
79a6989abb9363393f48cbd16a084b63ede3281b | diff --git a/src/main/java/hex/gbm/DHistogram.java b/src/main/java/hex/gbm/DHistogram.java
index <HASH>..<HASH> 100755
--- a/src/main/java/hex/gbm/DHistogram.java
+++ b/src/main/java/hex/gbm/DHistogram.java
@@ -73,6 +73,7 @@ public abstract class DHistogram<TDH extends DHistogram> extends Iced {
old = _maxIn;
... | Fix categorical handling to always use bitsets. Was doing ordinal comparison (treating categoricals as numerical) for #factors < #bins.
This is related to HEXDEV-<I>. | h2oai_h2o-2 | train |
0f019d31146ebe4bafff110095e909e0f66dec6e | diff --git a/plugins/UserCountryMap/js/realtime-map.js b/plugins/UserCountryMap/js/realtime-map.js
index <HASH>..<HASH> 100644
--- a/plugins/UserCountryMap/js/realtime-map.js
+++ b/plugins/UserCountryMap/js/realtime-map.js
@@ -203,8 +203,8 @@ RealTimeMap.run = function(config) {
function visitSymbolAttrs(r) {
... | minimum opacity set to <I> | matomo-org_matomo | train |
69275c6b2d22bee629d50aa2e05d09b320707993 | diff --git a/sentry-android-core/src/main/java/io/sentry/android/core/DefaultAndroidEventProcessor.java b/sentry-android-core/src/main/java/io/sentry/android/core/DefaultAndroidEventProcessor.java
index <HASH>..<HASH> 100644
--- a/sentry-android-core/src/main/java/io/sentry/android/core/DefaultAndroidEventProcessor.jav... | boot time should be UTC (getsentry/sentry-android#<I>) | getsentry_sentry-java | train |
e02c90887e2c6e5a0d51d2e825a03ea029123973 | diff --git a/changelog.txt b/changelog.txt
index <HASH>..<HASH> 100644
--- a/changelog.txt
+++ b/changelog.txt
@@ -14,7 +14,7 @@ to clearly indicate the caller is specifying a message with arguments to use in
* Introduced the ComparatorUtils.nullSafeArgumentsComparator(:Comparator) to protect against null arguments p... | Add the fromEnvironmentVariables() factory method to PropertiesBuilder to build a Properties object from System Environment Variables. | codeprimate-software_cp-elements | train |
21e1ff4a8a2ca8fd7ea3f3a5c8adcc1e9fe3c599 | diff --git a/pkg/sources/git/git.go b/pkg/sources/git/git.go
index <HASH>..<HASH> 100644
--- a/pkg/sources/git/git.go
+++ b/pkg/sources/git/git.go
@@ -107,7 +107,7 @@ func (s *Source) Init(aCtx context.Context, name string, jobId, sourceId int64,
}
s.git = NewGit(s.Type(), s.jobId, s.sourceId, s.name, s.verify, ... | Fix the order to correctly match the params in NewGit. (#<I>) | dxa4481_truffleHog | train |
3db3ac9c98e141996f4d1a7db89cbc8d8ffde443 | diff --git a/lib/services/user.go b/lib/services/user.go
index <HASH>..<HASH> 100644
--- a/lib/services/user.go
+++ b/lib/services/user.go
@@ -8,7 +8,6 @@ import (
"github.com/gravitational/teleport/lib/defaults"
"github.com/gravitational/teleport/lib/utils"
- "github.com/gravitational/configure/cstrings"
"gith... | Removing unix user name check from Teleport user name. | gravitational_teleport | train |
adf33f787ff8a981219c23cc9f0c011dc6168073 | diff --git a/tests/python/pants_test/tasks/test_junit_tests_integration.py b/tests/python/pants_test/tasks/test_junit_tests_integration.py
index <HASH>..<HASH> 100644
--- a/tests/python/pants_test/tasks/test_junit_tests_integration.py
+++ b/tests/python/pants_test/tasks/test_junit_tests_integration.py
@@ -7,6 +7,7 @@ f... | sanity check on generated cobertura xml report
One of our users was getting zero hits reported in the cobertura xml
report, which is used by the cobertura jenkins plugin. His generated
html was fine. We couldn't track down the error but this patch adds a
test for that condition. We needed some kind of test on the gene... | pantsbuild_pants | train |
03df850cda40deab4160c390336f9e964b593858 | diff --git a/Task/Collect/DataTypesCollector.php b/Task/Collect/DataTypesCollector.php
index <HASH>..<HASH> 100644
--- a/Task/Collect/DataTypesCollector.php
+++ b/Task/Collect/DataTypesCollector.php
@@ -26,6 +26,7 @@ class DataTypesCollector extends CollectorBase {
protected $testingDataTypes = [
'text' => TRUE... | Fixed missing data and field types from test sample collection list. | drupal-code-builder_drupal-code-builder | train |
c914429067da588ddcf217fac0db2eec9680a02b | diff --git a/MAVProxy/modules/mavproxy_speech.py b/MAVProxy/modules/mavproxy_speech.py
index <HASH>..<HASH> 100644
--- a/MAVProxy/modules/mavproxy_speech.py
+++ b/MAVProxy/modules/mavproxy_speech.py
@@ -7,8 +7,12 @@ from MAVProxy.modules.lib import mp_module
class SpeechModule(mp_module.MPModule):
def __init__(se... | speech: stop talking when speech unloaded
Also avoid appending the speech setting multiple times
as _keys grows | ArduPilot_MAVProxy | train |
b5437d0f693e0cf6cf7c1dd4ab4d1bd370e89c1c | diff --git a/spec/unit/appmgmt_spec.rb b/spec/unit/appmgmt_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/unit/appmgmt_spec.rb
+++ b/spec/unit/appmgmt_spec.rb
@@ -197,6 +197,17 @@ EOS
end
end
+
+ context "when using a site expression" do
+ it "the site expression is not evaluated in a node compila... | (PUP-<I>) Add evaluation of site expression
This adds evaluation of the site expression. It is treated analogous to
a node expression - but it contains the resources for all cross
node resources as apposed to the resources for a specific node.
This changes the environment compiler to prune the resulting catalog
from ... | puppetlabs_puppet | train |
139fccb31e4f1977a80acc9346552f60c9b3a715 | diff --git a/README.md b/README.md
index <HASH>..<HASH> 100644
--- a/README.md
+++ b/README.md
@@ -638,7 +638,7 @@ This will ignored if the top navigation layout is enabled, all menu items will a
To get a dynamic item placing you can add the `key` attribute, with this you can add a unique identifier to a add before ... | change the gate filter for more `can` entries (#<I>)
* change the gate filter for more `can` entries
* fix cs
* code improvments
* add test for multiple can
* fix cs
* fix tests
* fix tests | jeroennoten_Laravel-AdminLTE | train |
a70277fc9e4dd0ed4ef9a0480dd59131ca8ccf2e | diff --git a/container/controller.go b/container/controller.go
index <HASH>..<HASH> 100644
--- a/container/controller.go
+++ b/container/controller.go
@@ -343,13 +343,10 @@ func NewController(options ControllerOptions) (*Controller, error) {
glog.Errorf("Could not setup logstash files error:%s", err)
return c, ... | Log filebeat to container logs; update config to close file handles that don't get used; don't pick up old log files | control-center_serviced | train |
0c7d6f974a37583ff0ca3e905fd38fb7312b9f5e | diff --git a/core/config/rcm-core-config.php b/core/config/rcm-core-config.php
index <HASH>..<HASH> 100644
--- a/core/config/rcm-core-config.php
+++ b/core/config/rcm-core-config.php
@@ -273,12 +273,12 @@ return [
'post-libraries' => [],
'pre-rcm' => [],
'rcm' => [
- ... | ensure print css works in RCM | reliv_Rcm | train |
5e60ea906620857beae12a1fa64d715ff82844d5 | diff --git a/proton-c/bindings/python/proton/__init__.py b/proton-c/bindings/python/proton/__init__.py
index <HASH>..<HASH> 100644
--- a/proton-c/bindings/python/proton/__init__.py
+++ b/proton-c/bindings/python/proton/__init__.py
@@ -3757,6 +3757,10 @@ class Event(Wrapper, EventBase):
def _init(self):
pass
+... | PROTON-<I>: Expose Event.copy() to bindings
A handler is not supposed to keep a reference to the event.
In proton-j this is more obviaous as collector clears events before returning them to the pool. | apache_qpid-proton | train |
a2af7bb9280f2b52da0f8af3796fbe2e388025ff | diff --git a/activemodel/lib/active_model/dirty.rb b/activemodel/lib/active_model/dirty.rb
index <HASH>..<HASH> 100644
--- a/activemodel/lib/active_model/dirty.rb
+++ b/activemodel/lib/active_model/dirty.rb
@@ -58,7 +58,7 @@ module ActiveModel
#
# A newly instantiated object is unchanged:
#
- # person = Per... | use parentheses here, for the beard of the Prophet! [ci skip] | rails_rails | train |
dbd5e191b1f07288aed45b15e8ef3e0a674f6f6b | diff --git a/conftest.py b/conftest.py
index <HASH>..<HASH> 100644
--- a/conftest.py
+++ b/conftest.py
@@ -24,4 +24,4 @@ def pygen_output_dir(cwd_module_dir):
sys.path.append(path)
yield path
sys.path.remove(path)
- #shutil.rmtree(path, ignore_errors=False)
+ shutil.rmtree(path, ignore_errors=False... | reactivated cleanup of code generated during test | moltob_pymultigen | train |
7c15121f0b41b9c9f8881bbe9c8f4c7ada81acbf | diff --git a/spec/qu/instrumentation/log_subscriber_spec.rb b/spec/qu/instrumentation/log_subscriber_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/qu/instrumentation/log_subscriber_spec.rb
+++ b/spec/qu/instrumentation/log_subscriber_spec.rb
@@ -7,6 +7,7 @@ describe Qu::Instrumentation::LogSubscriber do
before(:e... | Ensure redis is clear for log subscriber spec. | bkeepers_qu | train |
b9e6cd48ba0e6576c32a79ddeeedeb06d8bf5a25 | diff --git a/cherry_picker/cherry_picker/cherry_picker.py b/cherry_picker/cherry_picker/cherry_picker.py
index <HASH>..<HASH> 100755
--- a/cherry_picker/cherry_picker/cherry_picker.py
+++ b/cherry_picker/cherry_picker/cherry_picker.py
@@ -191,7 +191,7 @@ To abort the cherry-pick and cleanup:
self.username,... | cherry-picker: Fix PR title (GH-<I>) | python_core-workflow | train |
53051ff77be071873358317118a6a55ec2ef34ba | diff --git a/src/SmscRuApi.php b/src/SmscRuApi.php
index <HASH>..<HASH> 100644
--- a/src/SmscRuApi.php
+++ b/src/SmscRuApi.php
@@ -54,7 +54,7 @@ class SmscRuApi
'fmt' => self::FORMAT_JSON,
];
- $params = array_merge($params, $base);
+ $params = array_merge($base, $params);
... | fix issues #<I> (#<I>) | laravel-notification-channels_smsc-ru | train |
fafc4e500b5aeb95a266605887fe8913aececf3a | diff --git a/bigquery/setup.py b/bigquery/setup.py
index <HASH>..<HASH> 100644
--- a/bigquery/setup.py
+++ b/bigquery/setup.py
@@ -55,7 +55,7 @@ REQUIREMENTS = [
setup(
name='google-cloud-bigquery',
- version='0.22.0',
+ version='0.22.1',
description='Python Client for Google BigQuery',
long_des... | Making sub-minor updates to libraries already on <I>.x | googleapis_google-cloud-python | train |
889f835f399b09928ebb1963c33986430caef314 | diff --git a/src/ORM/Association/ExternalAssociationTrait.php b/src/ORM/Association/ExternalAssociationTrait.php
index <HASH>..<HASH> 100644
--- a/src/ORM/Association/ExternalAssociationTrait.php
+++ b/src/ORM/Association/ExternalAssociationTrait.php
@@ -96,10 +96,11 @@ trait ExternalAssociationTrait {
public functio... | Changing the way eager loaded values are nested under each result.
The old way was making ResultSet confused about hydrating results having
the same association alias in the associaitons map | cakephp_cakephp | train |
3997f3431f479475f92dab1612abe2f99a0ab8d7 | diff --git a/cli/compose/convert/service.go b/cli/compose/convert/service.go
index <HASH>..<HASH> 100644
--- a/cli/compose/convert/service.go
+++ b/cli/compose/convert/service.go
@@ -616,11 +616,21 @@ func convertDeployMode(mode string, replicas *uint64) (swarm.ServiceMode, error)
serviceMode := swarm.ServiceMode{}
... | Added Swarm Job support to Stack Deploy
Added the support for both `global-job` and `replicated-job` to Docker
stack deploy. | docker_cli | train |
f9a8a1b45a01a91f8773ca344b2153d3ba038afc | diff --git a/src/main/java/com/shapesecurity/functional/data/ImmutableSet.java b/src/main/java/com/shapesecurity/functional/data/ImmutableSet.java
index <HASH>..<HASH> 100644
--- a/src/main/java/com/shapesecurity/functional/data/ImmutableSet.java
+++ b/src/main/java/com/shapesecurity/functional/data/ImmutableSet.java
@... | ImmutableSet::union and ImmutableSet::from (#<I>) | shapesecurity_shape-functional-java | train |
e298692eeeffbe143fdda771e01145996a488ce5 | diff --git a/formats/code.js b/formats/code.js
index <HASH>..<HASH> 100644
--- a/formats/code.js
+++ b/formats/code.js
@@ -14,12 +14,10 @@ class CodeBlockContainer extends Container {
}
html(index, length) {
- let text = this.domNode.innerText;
- // TODO find more robust solution for <select> turning into... | better code block to html conversion
also fixes firefox including <select> in innerText | quilljs_quill | train |
aee39c15217fe64830eb52f54539ed997938ff26 | diff --git a/lib/ui/src/core/context.js b/lib/ui/src/core/context.js
index <HASH>..<HASH> 100644
--- a/lib/ui/src/core/context.js
+++ b/lib/ui/src/core/context.js
@@ -89,6 +89,10 @@ export class Provider extends Component {
api.on(SET_STORIES, data => {
api.setStories(data.stories);
+
+ const options... | FIX setting of options when stories load | storybooks_storybook | train |
3fd0c69789c5d3896e50a76cbc6975347bde81ef | diff --git a/core-bundle/contao/classes/Hybrid.php b/core-bundle/contao/classes/Hybrid.php
index <HASH>..<HASH> 100644
--- a/core-bundle/contao/classes/Hybrid.php
+++ b/core-bundle/contao/classes/Hybrid.php
@@ -189,7 +189,7 @@ abstract class Hybrid extends \Frontend
*/
public function generate()
{
- if ($this->... | [Core] Show invisible elements in the back end preview (see #<I>) | contao_contao | train |
d9627657ab2fdc4a7f737541476a938005f69968 | diff --git a/jbpm-workitems/src/main/java/org/jbpm/process/workitem/rest/RESTWorkItemHandler.java b/jbpm-workitems/src/main/java/org/jbpm/process/workitem/rest/RESTWorkItemHandler.java
index <HASH>..<HASH> 100644
--- a/jbpm-workitems/src/main/java/org/jbpm/process/workitem/rest/RESTWorkItemHandler.java
+++ b/jbpm-worki... | JBPM-<I> - Typo in Runtime Exception Message (#<I>) | kiegroup_jbpm | train |
78a26d366c7c61171df9abb7dd9c2653ab42072c | diff --git a/config/module.config.php b/config/module.config.php
index <HASH>..<HASH> 100644
--- a/config/module.config.php
+++ b/config/module.config.php
@@ -603,7 +603,7 @@ return array(
'rcm-page-search' => array(
'type' => 'Zend\Mvc\Router\Http\Segment',
'options' => a... | Complete refactor of the product wizard. | reliv_Rcm | train |
0379f3155660c093e9f4633da9175e0251ae1b71 | diff --git a/lxd/device/nic_bridged.go b/lxd/device/nic_bridged.go
index <HASH>..<HASH> 100644
--- a/lxd/device/nic_bridged.go
+++ b/lxd/device/nic_bridged.go
@@ -1414,6 +1414,8 @@ func (d *nicBridged) State() (*api.InstanceStateNetwork, error) {
ips = append(ips, newIP)
}
+ hwAddr, _ := net.ParseMAC(d.config["h... | lxd/device/nic/bridged: Updated network.GetNeighbourIPs and ip package constant usage | lxc_lxd | train |
38faa0204d0839c76865a82c627555cbdee63408 | diff --git a/Annis-Web/src/main/webapp/javascript/annis/windowSearch.js b/Annis-Web/src/main/webapp/javascript/annis/windowSearch.js
index <HASH>..<HASH> 100644
--- a/Annis-Web/src/main/webapp/javascript/annis/windowSearch.js
+++ b/Annis-Web/src/main/webapp/javascript/annis/windowSearch.js
@@ -740,6 +740,7 @@ Ext.onRea... | added display : none to labelStyle | korpling_ANNIS | train |
b09a1e2634d86ddc6418aadff5a41e8658ee2749 | diff --git a/src/main/java/redis/clients/jedis/MultiKeyPipelineBase.java b/src/main/java/redis/clients/jedis/MultiKeyPipelineBase.java
index <HASH>..<HASH> 100644
--- a/src/main/java/redis/clients/jedis/MultiKeyPipelineBase.java
+++ b/src/main/java/redis/clients/jedis/MultiKeyPipelineBase.java
@@ -4,7 +4,7 @@ import ja... | MultiKeyPipelineBase and PipelineBase made public in order to make Pipeline and transaction mockable with Mockito | xetorthio_jedis | train |
0665333e8e1ed8e92ecc09e96a9e254b5b5fa720 | diff --git a/i18n_subsites/i18n_subsites.py b/i18n_subsites/i18n_subsites.py
index <HASH>..<HASH> 100644
--- a/i18n_subsites/i18n_subsites.py
+++ b/i18n_subsites/i18n_subsites.py
@@ -74,6 +74,7 @@ def create_lang_subsites(pelican_obj):
pelican_obj = cls(settings)
logger.debug("Generating i18n subsite ... | i<I>n_subsites: improve develop server support
1. main site url root fix
2. support autoreload mode
Also removed trailing slash on dir name. | getpelican_pelican-plugins | train |
6730f7d79c0b1a54ca49f45b226e1226d73210d7 | diff --git a/modules/component/component.js b/modules/component/component.js
index <HASH>..<HASH> 100644
--- a/modules/component/component.js
+++ b/modules/component/component.js
@@ -33,7 +33,7 @@ export default class Component extends Container {
* @return {Path2D}
*/
makePath (ctx) {
- const p... | :recycle: Refactoring code.
Prepend globals with "window" | pencil-js_pencil.js | train |
b8be48be6f27dbac3571825b67e9779fe6765855 | diff --git a/samcli/commands/local/lib/events.py b/samcli/commands/local/lib/events.py
index <HASH>..<HASH> 100644
--- a/samcli/commands/local/lib/events.py
+++ b/samcli/commands/local/lib/events.py
@@ -100,6 +100,7 @@ def generate_schedule_event(region):
:return dict: Dictionary representing the Schedule Event
... | add version field to schedule event generator; update test (#<I>)
undo bad format | awslabs_aws-sam-cli | train |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
--- a/src/Backbone.CollectionView.js
+++ b/src/Backbone.CollectionView.js
@@ -781,7 +781,14 @@
if( clickedItemId )
{
- // a list item was clicked
+ // Exit if an unselectable item was clicked
+ if... | Fixed bug with the behavior of clicking an unselectable item | rotundasoftware_backbone.collectionView | train |
505077c6878734248c33a09b0b5bf755f720bb40 | diff --git a/extension/rsb/com/src/main/java/org/openbase/jul/extension/rsb/com/RSBRemoteService.java b/extension/rsb/com/src/main/java/org/openbase/jul/extension/rsb/com/RSBRemoteService.java
index <HASH>..<HASH> 100644